/*
 * Copyright (C) 2012 Michal Simek <monstr@monstr.eu>
 * Copyright (C) 2012 Xilinx, Inc. All rights reserved.
 *
 * SPDX-License-Identifier:	GPL-2.0+
 */
#include <common.h>
#include <asm/io.h>
#include <asm/arch/clk.h>
#include <asm/arch/sys_proto.h>
#include <asm/arch/hardware.h>
#include <asm/arch-zynq/bootconfig.h>

#define ZYNQ_SILICON_VER_MASK	0xF0000000
#define ZYNQ_SILICON_VER_SHIFT	28

int arch_cpu_init(void)
{
	zynq_slcr_unlock();
#ifndef CONFIG_SPL_BUILD
	/* Device config APB, unlock the PCAP */
	writel(0x757BDF0D, &devcfg_base->unlock);
	writel(0xFFFFFFFF, &devcfg_base->rom_shadow);

#if (CONFIG_SYS_SDRAM_BASE == 0)
	/* remap DDR to zero, FILTERSTART */
	writel(0, &scu_base->filter_start);

	/* OCM_CFG, Mask out the ROM, map ram into upper addresses */
	writel(0x1F, &slcr_base->ocm_cfg);
	/* FPGA_RST_CTRL, clear resets on AXI fabric ports */
	writel(0x0, &slcr_base->fpga_rst_ctrl);
	/* Set urgent bits with register */
	writel(0x0, &slcr_base->ddr_urgent_sel);
	/* Urgent write, ports S2/S3 */
	writel(0xC, &slcr_base->ddr_urgent);
#endif
#endif
#ifdef CONFIG_TARGET_ZYNQ_UCB7020
    /* setup pins for UCB version */
    writel(0x1701, &slcr_base->mio_pin[34]);
    writel(0x1701, &slcr_base->mio_pin[35]);
    writel(0x1701, &slcr_base->mio_pin[36]);
    writel(0x1701, &slcr_base->mio_pin[37]);
	/* use GPIO 34..37 for strapping input */
	writel((readl(ZYNQ_GPIO_DIRM1_REG) & ~0x3c), ZYNQ_GPIO_DIRM1_REG);
	writel((readl(ZYNQ_GPIO_OEN1_REG) & ~0x3c), ZYNQ_GPIO_OEN1_REG);
    /* make GPIO 13 output for EEPROM WP */
	writel(readl(ZYNQ_GPIO_DIRM0_REG) | (3 << GPIO_PIN_EEPROM_WP),
        ZYNQ_GPIO_DIRM0_REG);
	writel(readl(ZYNQ_GPIO_OEN0_REG) | (3 << GPIO_PIN_EEPROM_WP),
         ZYNQ_GPIO_OEN0_REG);
    /* QSPI will use manual GPIO handling. Prepare GPIO here */
    writel(0xfffc0003, ZYNQ_GPIO_DATA0_L_MASK_REG); /* clear output, negated */
    writel(readl(ZYNQ_GPIO_DIRM0_REG) | 3, ZYNQ_GPIO_DIRM0_REG); /*set to output */
    writel(readl(ZYNQ_GPIO_OEN0_REG) | 3, ZYNQ_GPIO_OEN0_REG); /* and enable it*/

#endif 
	zynq_clk_early_init();
	zynq_slcr_lock();

	return 0;
}

unsigned int zynq_get_silicon_version(void)
{
	unsigned int ver;

	ver = (readl(&devcfg_base->mctrl) &
	       ZYNQ_SILICON_VER_MASK) >> ZYNQ_SILICON_VER_SHIFT;

	return ver;
}

void reset_cpu(ulong addr) /*lint -e{716,715} this function won't return! */
{
	zynq_slcr_cpu_reset();
	while (1)
		;
}

#ifndef CONFIG_SYS_DCACHE_OFF
void enable_caches(void)
{
	/* Enable D-cache. I-cache is already enabled in start.S */
	dcache_enable();
}
#endif
