/********************************************************************************
 *            Copyright (c  ) 2015  2015 by esd electronic system design gmbh
 *
 *  This software is copyrighted by and is the sole property of 
 *  esd gmbh.  All rights, title, ownership, or other interests
 *  in the software remain the property of esd gmbh. This
 *  software may only be used in accordance with the corresponding
 *  license agreement.  Any unauthorized use, duplication, transmission,  
 *  distribution, or disclosure of this software is expressly forbidden.
 *
 *  This Copyright notice may not be removed or modified without prior
 *  written consent of esd gmbh.
 *
 *  esd gmbh, reserves the right to modify this software without notice.
 *
 *  electronic system design gmbh          Tel. +49-511-37298-0
 *  Vahrenwalder Str 207                   Fax. +49-511-37298-68 
 *  30165 Hannover                         http://www.esd.eu
 *  Germany                                sales@esd.eu
 *
 * SPDX-License-Identifier:	GPL-2.0+
 *
 ********************************************************************************
 */

#include <common.h>
#include <asm/io.h>
#include <asm/arch/hardware.h>
#include <status_led.h>

DECLARE_GLOBAL_DATA_PTR;

/* for the eval board, we control DS23 (MIO 10) and DS12 (MIO 8) */
#define ZYNQ_SLCR_BASE 			0xf8000000	/* slcr base address register */
#define ZYNQ_SLCR_LOCK_REG		(ZYNQ_SLCR_BASE + 0x0004) /* unlock register */
#define ZYNQ_SLCR_UNLOCK_REG		(ZYNQ_SLCR_BASE + 0x0008) /* unlock register */
#define ZYNQ_SLCR_LOCK_STAT		(ZYNQ_SLCR_BASE + 0x000c)	/* lock status register */
#define ZYNQ_SLCR_UNLOCK_MAGIC		(ZYNQ_SLCR_BASE + 0xdf0d) /* magic to write to unlock register */
#define ZYNQ_SLCR_LOCK_MAGIC		(ZYNQ_SLCR_BASE + 0x767b) /* magic to write to unlock register */

static int led_init_done = 0;
static int is_locked;

void __led_init (led_id_t mask, int state /*lint -e{715} */)
{
	if (led_init_done) return;
	
	is_locked = readl(ZYNQ_SLCR_LOCK_STAT);
	if (is_locked) {
		writel(ZYNQ_SLCR_UNLOCK_MAGIC, ZYNQ_SLCR_UNLOCK_REG);
	}
#ifdef CONFIG_ZYNQ_EVALBOARD
	writel(0x600, &slcr_base->mio_pin[8]);	/* disable tristate and route to GPIO */
	writel(0x600, &slcr_base->mio_pin[10]);	/* disable tristate and route to GPIO */
#else
	/* red and yellow LED */
	writel(0x600, &slcr_base->mio_pin[38]);	/* disable tristate and route to GPIO */
	writel(0x600, &slcr_base->mio_pin[39]);
	/* 8 debug LEDs */
	writel(0x600, &slcr_base->mio_pin[40]);
	writel(0x600, &slcr_base->mio_pin[41]);
	writel(0x600, &slcr_base->mio_pin[42]);
	writel(0x600, &slcr_base->mio_pin[43]);
	writel(0x600, &slcr_base->mio_pin[44]); 
	writel(0x600, &slcr_base->mio_pin[45]);
	writel(0x600, &slcr_base->mio_pin[46]);
	writel(0x600, &slcr_base->mio_pin[47]);
#endif

	/* setup lock state again, if is had been set preiously */
	if (is_locked) {
		writel(ZYNQ_SLCR_LOCK_MAGIC, ZYNQ_SLCR_LOCK_REG);
	}
	/* set GPIO output */
#ifdef CONFIG_ZYNQ_EVALBOARD
	mask = readl(ZYNQ_GPIO_DIRM0_REG);
	mask |= ((1<<8) | (1<<10));
	writel(mask, ZYNQ_GPIO_DIRM0_REG);

	mask = readl(ZYNQ_GPIO_OEN0_REG);
	mask |= ((1<<8) | (1<<10));
	writel(mask, ZYNQ_GPIO_OEN0_REG);

	/* turn OFF LEDs */
	mask = readl(ZYNQ_GPIO_DATA0_REG);
	mask &= ~((1<<8) | (1<<10));
	writel(mask, ZYNQ_GPIO_DATA0_REG);
#else
	/* use GPIO 38..47. Bank1 means bits 6..15 */
	mask = readl(ZYNQ_GPIO_DIRM1_REG);
	mask |= 0xffc0;
	writel(mask, ZYNQ_GPIO_DIRM1_REG);

	mask = readl(ZYNQ_GPIO_OEN1_REG);
	mask |= 0xffc0;
	writel(mask, ZYNQ_GPIO_OEN1_REG);

	/* turn OFF LEDs */
	mask = readl(ZYNQ_GPIO_DATA1_REG);
	mask &= ~(0x00c0);
	mask |= 0xff00;	/* inverted debug since pulled up! */
	writel(mask, ZYNQ_GPIO_DATA1_REG);
#endif
	led_init_done = 1;
}

void __led_set (led_id_t mask, int state)
{
	unsigned int bit_mask;

	if (!led_init_done) __led_init(0,0);

#ifdef CONFIG_ZYNQ_EVALBOARD
	bit_mask =  (0xffff & ~mask) << 16;	/* clear bit in mask we modify */
	if (state) bit_mask |= mask;
	writel(bit_mask, ZYNQ_GPIO_DATA0_L_MASK_REG);
#else
	mask <<= 6;	/* shift to GPIO locations */
	bit_mask =  (0xffff & ~mask) << 16;	/* clear bit in mask we modify */
    /* only yellow and red leds are strait, others are inverted */
	if (state)
	    bit_mask |= (mask & 0xc0);  /* set leds */
    else 
	    bit_mask |= (mask & 0xff00);   /* inverted! */
	writel(bit_mask, ZYNQ_GPIO_DATA1_L_MASK_REG);
#endif
}

void __led_toggle (led_id_t mask)
{
	unsigned int state, bit_mask;
	if (!led_init_done) __led_init(0,0);

#ifdef CONFIG_ZYNQ_EVALBOARD
	state = readl(ZYNQ_GPIO_DATA0_REG) & mask;
	bit_mask =  (0xffff & ~mask) << 16;	/* clear bit in mask we modify */
	bit_mask |= (state ^ mask);
	writel(bit_mask, ZYNQ_GPIO_DATA0_L_MASK_REG);
#else
	mask <<= 6;	/* shift ot GPIO locations */
	state = readl(ZYNQ_GPIO_DATA1_REG) & mask;
	bit_mask =  (0xffff & ~mask) << 16;	/* clear bit in mask we modify */
	bit_mask |= (state ^ mask);
	writel(bit_mask, ZYNQ_GPIO_DATA1_L_MASK_REG);
#endif
}

void red_led_on(void)
{
    __led_set(1,1);
}


void red_led_off(void)
{
    __led_set(1,0);
}


void yellow_led_on(void)
{
    __led_set(2,1);
}


void yellow_led_off(void)
{
    __led_set(2,0);
}

