/* XXX ESD header */

#include <common.h>
#include <config.h>
#include <watchdog.h>
#include <command.h>
#include <image.h>
#include <asm/byteorder.h>
#include <asm/io.h>


#define RAMDISK_BLOCKSIZE 512

static block_dev_desc_t ram_dev_desc;
static unsigned char *disk_base;
static unsigned int disk_size;

static ulong ram_read(int device, lbaint_t blknr, lbaint_t blkcnt, void *buffer)
{
	if (blkcnt > 0) {
	        memmove((void *)buffer, disk_base + blknr * RAMDISK_BLOCKSIZE, blkcnt * RAMDISK_BLOCKSIZE);
	}
	return blkcnt;
}

static ulong ram_write(int device, lbaint_t blknr, lbaint_t blkcnt, const void *buffer)
{
	if (blkcnt > 0) {
	        memmove(disk_base + blknr * RAMDISK_BLOCKSIZE, buffer, blkcnt * RAMDISK_BLOCKSIZE);
	}
	return blkcnt;
}

int ramdisk_init(unsigned int start_addr, unsigned len)
{
	disk_base = (unsigned char *)start_addr;
	disk_size = len / RAMDISK_BLOCKSIZE;

	ram_dev_desc.type = DEV_TYPE_HARDDISK;
	ram_dev_desc.if_type = IF_TYPE_MMC;
	ram_dev_desc.dev = 0;
	ram_dev_desc.part_type = PART_TYPE_DOS;
	ram_dev_desc.blksz = RAMDISK_BLOCKSIZE;
	ram_dev_desc.log2blksz = 9;
	ram_dev_desc.lba = len / ram_dev_desc.blksz;
	ram_dev_desc.block_read = ram_read;
	ram_dev_desc.block_write = ram_write;
	strcpy(ram_dev_desc.vendor, "ramdisk");
	/* ram_ident(&ram_dev_desc); we could fill in some more details... */
	dev_print(&ram_dev_desc);

	if ((ram_dev_desc.lba > 0) && (ram_dev_desc.blksz > 0)) {
		/* initialize partition type */
		init_part(&ram_dev_desc);
	}
	return 0;

}

block_dev_desc_t *ram_get_dev(int dev)
{
        return (dev < 1) ? &ram_dev_desc : NULL;
}

